@@ -3,22 +3,39 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use RDF::aREF::Query;
+use RDF::aREF::Decoder;
+use RDF::aREF::Encoder;
 use Scalar::Util qw(blessed);
 use Carp qw(croak);
 
 use parent 'Exporter';
-our @EXPORT = qw(decode_aref aref_query aref_query_map);
-our @EXPORT_OK = qw(aref_to_trine_statement);
-our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
+our @EXPORT = qw(decode_aref encode_aref aref_query aref_query_map);
+our %EXPORT_TAGS = (all => [@EXPORT]);
 
 sub decode_aref(@) { ## no critic
     my ($aref, %options) = @_;
     RDF::aREF::Decoder->new(%options)->decode($aref);
 }
 
+sub encode_aref(@) { ## no critic
+    my ($source, %options) = @_;
+    my $encoder = RDF::aREF::Encoder->new(%options);
+    my $aref = {};
+
+    if (blessed $source and $source->isa('RDF::Trine::Iterator')) {
+        $encoder->add_iterator( $aref, $source );
+    } elsif (blessed $source and $source->isa('RDF::Trine::Model')) {
+        $encoder->add_iterator( $aref, $source->as_stream );
+    }
+    
+    # TODO: encode hashref or callback code reference
+    
+    return $aref;
+}
+
 sub aref_query {
     my ($graph, $origin, $query) = @_ < 3 ? ($_[0], undef, $_[1]) : @_;
 
@@ -54,12 +71,6 @@ sub aref_query_map {
     \%record;
 }
 
-# FIXME: this is undocumented but used by Catmandu::RDF. Remove?
-sub aref_to_trine_statement {
-    # warn 'RDF::aREF::aref_to_trine_statement will be removed!';
-    RDF::aREF::Decoder::aref_to_trine_statement(@_);
-}
-
 1;
 __END__
 
@@ -110,6 +121,10 @@ RDF::aREF - Another RDF Encoding Form
     decode_aref( $rdf, callback => $model );
     print RDF::Trine::Serializer->new('Turtle')->serialize_model_to_string($model);
 
+    my $model = RDF::Trine::Model->new;
+    RDF::Trine::Parser->parse_url_into_model($url, $model);
+    my $aref = encode_aref $model;
+
 =head1 DESCRIPTION
 
 B<aREF> (L<another RDF Encoding Form|http://gbv.github.io/aREF/>) is an
@@ -122,11 +137,16 @@ and for querying parts of an RDF graph (L<RDF::aREF::Query>).
 
 The following functions are exported by default.
 
-=head2 decode_aref( $aref, [ %options ] )
+=head2 decode_aref( $aref [, %options ] )
 
 Decodes an aREF document given as hash reference with L<RDF::aREF::Decoder>.
 Equivalent to C<< RDF::aREF::Decoder->new(%options)->decode($aref) >>.
 
+=head2 encode_aref( $rdf [, %options ] )
+
+Create a new L<RDF::aREF::Encoder> and construct an aREF subject map with
+RDF triples given as L<RDF::Trine::Model> or L<RDF::Trine::Model::Iterator>.
+
 =head2 aref_query( $graph, [ $origin ], $query )
 
 Query parts of an aREF data structure. See L<RDF::aREF::Query> for details.
